@@ -20,7 +20,7 @@ grid1[::2, -1] = 2
 p = js.grace()
 for i, fa in enumerate([0.05, 0.1, 0.2, 0.5, 1], 1):
     grid1[::2, -2] = fa
-    fq = js.ff.cloudScattering(q, grid1, relError=0, formfactor=ff)
+    fq = js.ff.cloudScattering(q, grid1, relError=0, formfactoramp=ff)
     p.plot(fq, sy=[1, 0.4, i], le='gaussian coils fa={0:.2f}'.format(fa))
 
 p.yaxis(scale='l', label='I(Q)')
@@ -33,7 +33,7 @@ p.save('connected_linearPearls.png', size=(900, 900), dpi=150)
 # same with orientation in 2D
 grid1[::2, -2] = 0.1
 qxzw = np.mgrid[-6:6:50j, -6:6:50j].reshape(2, -1).T
-ffe = js.ff.orientedCloudScattering(qxzw, grid1, coneangle=5, nCone=10, rms=0)
+ffe = js.ff.orientedCloudScattering(qxzw, grid1, mosaicity=[5,0,0], nCone=10, rms=0)
 fig = js.mpl.surface(ffe.X, ffe.Z, ffe.Y)
 fig.axes[0].set_title(r'cos**2 for Z and slow decay for X due to 5 degree cone')
 fig.show()
