@@ -427,6 +427,42 @@ class fortranTest(unittest.TestCase):
             warnings.warn('Fortran module not found')
 
 
+class continTest(unittest.TestCase):
+    """
+    Test if contin works if it was installed
+    """
+    setupdone = False
+
+    @classmethod
+    def setUp(self):
+        if self.setupdone: return
+
+        if js.dls.continexe:
+            t = js.loglist(1,10000, 1000)   # times in microseconds
+            q = 4*np.pi/1.333/632*np.sin(np.pi/2) # 90 degrees for 632 nm , unit is 1/nm**2
+            D = 0.05*1000  # nm**2/ns * 1000 = units nm**2/microseconds
+            noise = 0.0001  # typical < 1e-3
+            data = js.dA(np.c_[t,0.95*np.exp(-q**2*D*t)**2+noise * np.sign(np.sin(np.r_[:len(t)]*9.5))].T)
+            # add attributes to overwrite defaults
+            data.Angle      =90    # scattering angle in degrees
+            data.Temperature=293   # Temperature of measurement  in K
+            data.Viscosity  =1     # viscosity cPoise
+            data.Refractive =1.333 # refractive index
+            data.Wavelength =632   # wavelength
+            # do CONTIN
+            self.dr=js.dls.contin(data,distribution='x')
+        else:
+            self.dr = 'nocontin'
+            warnings.warn('Fortran module not found')
+
+    def test_contin(self):
+        if js.dls.continexe:
+            self.assertAlmostEqual(self.dr[0].contin_bestFit.ipeaks[0][1], 45.4, 1)
+            self.assertAlmostEqual(self.dr[0].contin_bestFit.ipeaks[0][2], 6.02, 1)
+        else:
+            print('No Contin found')
+
+
 def core_shellsphere(q, Rc, Rs, bc, bs, alpha, solventSLD=0):
     return js.ff.multiShellSphere(q, [Rc, Rs],
                                   [bc, ((bs - solventSLD) * np.r_[1:Rs + 1:9j] ** (-alpha)) + solventSLD],
@@ -917,6 +953,7 @@ def suite():
     s.addTest(loader.loadTestsFromTestCase(dynamicTest))
     s.addTest(loader.loadTestsFromTestCase(test_imagehash.allimageHashTest))
     # s.addTest(loader.loadTestsFromTestCase(plotTest))
+    s.addTest(loader.loadTestsFromTestCase(continTest))
 
     return s
 
